@@ -92,7 +92,7 @@ Configuration::Configuration(const QJsonObject &inputData, const QString &plugin
 
 Configuration::Configuration(const QJsonObject &inputData, const QString &pluginTypeName, const QJsonObject &pluginType, const KPluginMetaData &pluginInformation, QObject* parent)
     : QObject(parent)
-    , d_ptr(new ConfigurationPrivate {inputData, pluginTypeName, pluginType, pluginInformation, true})
+    , d_ptr(new ConfigurationPrivate {inputData, pluginTypeName, pluginType, pluginInformation, !qEnvironmentVariableIsSet("KDE_PURPOSE_LOCAL_JOBS")})
 {}
 
 Configuration::~Configuration()
@@ -120,13 +120,14 @@ QJsonObject Configuration::data() const
 bool Configuration::isReady() const
 {
     Q_D(const Configuration);
+    bool ok = true;
     Q_FOREACH(const QJsonValue& arg, neededArguments()) {
         if(!d->m_inputData.contains(arg.toString())) {
-            qDebug() << "missing..." << arg.toString();
-            return false;
+            qDebug() << "missing mandatory argument" << arg.toString();
+            ok = false;
         }
     }
-    return true;
+    return ok;
 }
 
 QJsonArray Configuration::neededArguments() const
